<?php
namespace Quizpalme\Camaliga\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 Kurt Gusbeth <info@quizpalme.de>
 *  
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 *
 *
 * @package camaliga
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class BackendController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController {

	/**
	 * contentRepository
	 *
	 * @var \Quizpalme\Camaliga\Domain\Repository\ContentRepository
	 * @inject
	 */
	protected $contentRepository;
	
	/**
	 * Zähler
	 *
	 * @var \integer
	 */
	protected $nr = 0;
	

	/**
	 * Ordner-ID
	 *
	 * @return integer
	 */
	protected function getCurrentPageId() {
		$pageId = (integer) \TYPO3\CMS\Core\Utility\GeneralUtility::_GP('id');
		if ($pageId > 0) {
		  return $pageId;
		}
		// get current site root
		$rootPages = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows('uid', 'pages', 'deleted=0 AND hidden=0 AND is_siteroot=1', '', '', '1');
		if (count($rootPages) > 0) {
		  return (integer) $rootPages[0]['uid'];
		}
		// fallback
		return (integer) self::DEFAULT_BACKEND_STORAGE_PID;
	}

	/**
	 * action index
	 *
	 * @return void
	 */
	public function indexAction() {
		$this->view->assign('pid', intval($this->getCurrentPageId()));
	}

	/**
	 * action thumb
	 *
	 * @return void
	 */
	public function thumbAction() {
		$pid = intval($this->getCurrentPageId());
		$saved = 0;
		
		// save new order first
		if ($this->request->hasArgument('camelements')) {
			$updateA = array();
			$order = $this->request->getArgument('camelements');
			if (is_array($order)) {
				foreach ($order as $key => $value) {
					if ($key > 0 && $value > 0) {
						$updateA['sorting'] = $value;
						$GLOBALS['TYPO3_DB']->exec_UPDATEquery('tx_camaliga_domain_model_content', 'uid=' . intval($key), $updateA);
						$saved = 1;
					}
				}
			}
		}
		
		// Elemente sortiert holen
		$contents = $this->contentRepository->findAll('sorting', 'asc', FALSE, array($pid));
		
		if (class_exists('t3lib_utility_VersionNumber'))
			$this->view->assign('typo37', 0);
		else 
			$this->view->assign('typo37', 1);
		$this->view->assign('pid', $pid);
		$this->view->assign('saved', $saved);
		$this->view->assign('contents', $contents);
	}
	
	/**
	 * action Karussell-import
	 *
	 * @return void
	 */
	public function importAction() {
		$oldIDs = array();
		$pid = intval($this->getCurrentPageId());
		$res = $GLOBALS['TYPO3_DB']->sql_query("SHOW TABLES LIKE 'tx_karussell_inhalt'");
		if ($GLOBALS['TYPO3_DB']->sql_num_rows($res)>0) {
			// get Karussell-entries for current PID
			$entries = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows('*', 'tx_karussell_inhalt', 'deleted=0 AND hidden=0 AND pid=' . $pid, 'sys_language_uid, sorting', '', '');
			if (count($entries) > 0) {
				if ($this->request->hasArgument('cimport') || $this->request->hasArgument('dimport')) {
					// Import
					$insert = array();
					$insert['pid'] = $pid;
					$insert['tstamp'] = time();
					$insert['crdate'] = time();
					$insert['cruser_id'] = $GLOBALS['BE_USER']->user['uid'];
					for ($i=0; $i<count($entries); $i++) {
						$insert['sorting'] = $entries[$i]['sorting'];
						$insert['title'] = $entries[$i]['titel'];
						$insert['shortdesc'] = $entries[$i]['meldung'];
						$insert['link'] = $entries[$i]['link'];
						$insert['image'] = $this->checkImage($entries[$i]['bild']);
						$insert['t3_origuid'] = ($entries[$i]['t3_origuid']) ? intval($oldIDs[$entries[$i]['t3_origuid']]) : 0;
						$insert['l10n_parent'] = ($entries[$i]['l10n_parent']) ? intval($oldIDs[$entries[$i]['l10n_parent']]) : 0;
						$insert['sys_language_uid'] = $entries[$i]['sys_language_uid'];
						$success = $GLOBALS['TYPO3_DB']->exec_INSERTquery('tx_camaliga_domain_model_content', $insert);
						if ($success){
		                    $oldIDs[$entries[$i]['uid']] = $GLOBALS['TYPO3_DB']->sql_insert_id();
						}
						copy(PATH_site . 'uploads/tx_karussell/'.$entries[$i]['bild'], PATH_site . 'uploads/tx_camaliga/' . $insert['image']);
						if ($this->request->hasArgument('dimport'))
							unlink(PATH_site . 'uploads/tx_karussell/'.$entries[$i]['bild']);
					}
					$this->flashMessageContainer->add(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('LLL:EXT:camaliga/Resources/Private/Language/locallang_be.xlf:import.ok', 'OK'));
					if ($this->request->hasArgument('dimport')) {
						$GLOBALS['TYPO3_DB']->exec_DELETEquery('tx_karussell_inhalt', 'deleted=0 AND hidden=0 AND pid=' . $pid);
						$this->flashMessageContainer->add(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('LLL:EXT:camaliga/Resources/Private/Language/locallang_be.xlf:import.del', 'deleted'));
					}
				}
				
				$this->view->assign('entries', $entries);
				$this->view->assign('error', 0);
			} else {
				$this->view->assign('error', 1);
			}
		} else {
			$this->view->assign('error', 1);
		}
	}

	/**
	 * action tt_news-import
	 *
	 * @return void
	 */
	public function importNewsAction() {
		$pid = intval($this->getCurrentPageId());
		$oldIDs = array();
		$res = $GLOBALS['TYPO3_DB']->sql_query("SHOW TABLES LIKE 'tt_news'");
		if ($GLOBALS['TYPO3_DB']->sql_num_rows($res)>0) {
			// get News-entries for current PID
			$entries = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows('*', 'tt_news', 'deleted=0 AND hidden=0 AND pid=' . $pid, '', 'tstamp DESC', '');
			if (count($entries) > 0) {
				if ($this->request->hasArgument('cimport') || $this->request->hasArgument('dimport')) {
					// Import
					$insert = array();
					$insert['pid'] = $pid;
					$insert['cruser_id'] = $GLOBALS['BE_USER']->user['uid'];
					for ($i=0; $i<count($entries); $i++) {
						$link = $entries[$i]['links'];
						if ($link) {
							if (strtoupper(substr($link, 0, 5)) == '<LINK') {
								$linkArray = explode(' ', $link);
								$link = $linkArray[1];
							}
						} else {
							$link = '';
						}
						$insert['sorting'] = $i+1;
						$insert['tstamp'] = $entries[$i]['tstamp'];
						$insert['crdate'] = $entries[$i]['crdate'];
						$insert['title'] = $entries[$i]['title'];
						$insert['shortdesc'] = ($entries[$i]['short']) ? $entries[$i]['short'] : '';
						$insert['longdesc'] = ($entries[$i]['bodytext']) ? $entries[$i]['bodytext'] : '';
						$insert['link'] = $link;
						$insert['image'] = $this->checkImage($entries[$i]['image']);
						$insert['sys_language_uid'] = $entries[$i]['sys_language_uid'];
						$success = $GLOBALS['TYPO3_DB']->exec_INSERTquery('tx_camaliga_domain_model_content', $insert);
						if ($success){
							$oldIDs[$entries[$i]['uid']] = $GLOBALS['TYPO3_DB']->sql_insert_id();
						}
						if ($entries[$i]['image']) {
							copy(PATH_site . 'uploads/pics/' . $entries[$i]['image'], PATH_site . 'uploads/tx_camaliga/' . $insert['image']);
							if ($this->request->hasArgument('dimport') && is_file(PATH_site.'uploads/pics/' . $entries[$i]['image']))
								unlink(PATH_site.'uploads/pics/' . $entries[$i]['image']);
						}
					}
					
					// Kategorien ebenfalls kopieren
					$i = 0;
					$catArray = array();
					$mmArray  = array();
					foreach ($oldIDs as $key => $value) {
						$res = $GLOBALS['TYPO3_DB']->exec_SELECTquery('mm.uid_foreign, mm.uid_local, mm.sorting AS mmsort, cat.uid, cat.crdate, cat.tstamp, cat.title, cat.description, cat.sorting AS catsort',
								'`tt_news_cat` AS cat, `tt_news_cat_mm` AS mm',
								'cat.uid=mm.uid_foreign AND mm.uid_local=' . $key);
						$rows = $GLOBALS['TYPO3_DB']->sql_num_rows($res);
						if ($rows>0) {
							while($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res)){
								$uid = $row['uid'];
								$catArray[$uid] = array();
								$catArray[$uid]['crdate'] = $row['crdate'];
								$catArray[$uid]['tstamp'] = $row['tstamp'];
								$catArray[$uid]['title'] = $row['title'];
								$catArray[$uid]['description'] = $row['description'];
								$catArray[$uid]['sorting'] = $row['catsort'];
								$mmArray[$i] = array();
								$mmArray[$i]['uid_local'] = $row['uid_local'];		// Die News
								$mmArray[$i]['uid_foreign'] = $row['uid_foreign'];	// Die Kategorie
								$mmArray[$i]['sorting'] = $row['mmsort'];
								$i++;
							}
						}
						$GLOBALS['TYPO3_DB']->sql_free_result($res);
					}
					// Kategorien einfügen
					foreach ($catArray as $key => $values) {
						$values['pid'] = $pid;
						$values['cruser_id'] = $GLOBALS['BE_USER']->user['uid'];
						$success = $GLOBALS['TYPO3_DB']->exec_INSERTquery('sys_category', $values);
						if ($success){
							$catArray[$key]['uid'] = $GLOBALS['TYPO3_DB']->sql_insert_id();
						}
					}
					// Kategorie-Relationen einfügen
					$mmInsertArray = array('tablenames' => 'tx_camaliga_domain_model_content', 'fieldname' => 'categories');
					foreach ($mmArray as $key => $values) {
						$mmInsertArray['uid_local'] = $catArray[$values['uid_foreign']]['uid'];	// Die Kategorie
						$mmInsertArray['uid_foreign'] = $oldIDs[$values['uid_local']];			// Das Camaliga-Element
						$mmInsertArray['sorting'] = $values['sorting'];
						$success = $GLOBALS['TYPO3_DB']->exec_INSERTquery('sys_category_record_mm', $mmInsertArray);
					}
					
					// Meldung
					$this->flashMessageContainer->add(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('LLL:EXT:camaliga/Resources/Private/Language/locallang_be.xlf:import.ok', 'OK'));
					if ($this->request->hasArgument('dimport')) {
						$GLOBALS['TYPO3_DB']->exec_DELETEquery('tt_news', 'deleted=0 AND hidden=0 AND pid=' . $pid);
						$this->flashMessageContainer->add(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('LLL:EXT:camaliga/Resources/Private/Language/locallang_be.xlf:import.del', 'deleted'));
					}
				}
				
				$this->view->assign('entries', $entries);
				$this->view->assign('error', 0);
			} else {
				$this->view->assign('error', 1);
			}
		} else {
			$this->view->assign('error', 1);
		}
	}
	

	/**
	 * action mv_cooking-import
	 *
	 * @return void
	 */
	public function importCookingAction() {
		$pid = intval($this->getCurrentPageId());
		$oldIDs = array();
		$res = $GLOBALS['TYPO3_DB']->sql_query("SHOW TABLES LIKE 'tx_mvcooking_recette'");
		if ($GLOBALS['TYPO3_DB']->sql_num_rows($res)>0) {
			// get Cooking-entries for current PID
			$entries = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows('*', 'tx_mvcooking_recette', 'deleted=0 AND hidden=0 AND pid=' . $pid, '', 'nom ASC', '');
			if (count($entries) > 0) {
				if ($this->request->hasArgument('cimport') || $this->request->hasArgument('dimport')) {
					// Import
					$insert = array();
					$insert['pid'] = $pid;
					$insert['cruser_id'] = $GLOBALS['BE_USER']->user['uid'];
					for ($i=0; $i<count($entries); $i++) {
						$insert['sorting'] = $i+1;
						$insert['tstamp'] = $entries[$i]['tstamp'];
						$insert['crdate'] = $entries[$i]['crdate'];
						$insert['title'] = $entries[$i]['nom'];
						$insert['shortdesc'] = ($entries[$i]['ingredient']) ? $entries[$i]['ingredient'] : '';
						$insert['longdesc'] = ($entries[$i]['recette']) ? $entries[$i]['recette'] : '';
						$insert['image'] = $this->checkImage($entries[$i]['image']);
						$insert['street'] = $entries[$i]['remarque'];
						$insert['phone'] = $entries[$i]['variante'];
						$insert['custom1'] = $entries[$i]['personne'];
						$insert['custom2'] = $entries[$i]['preparation'];
						$insert['custom3'] = $entries[$i]['cuisson'];
						$insert['sys_language_uid'] = $entries[$i]['sys_language_uid'];
						$success = $GLOBALS['TYPO3_DB']->exec_INSERTquery('tx_camaliga_domain_model_content', $insert);
						if ($success){
							$oldIDs[$entries[$i]['uid']] = $GLOBALS['TYPO3_DB']->sql_insert_id();
						}
						if ($entries[$i]['image']) {
							copy(PATH_site . 'uploads/tx_mvcooking/' . $entries[$i]['image'], PATH_site . 'uploads/tx_camaliga/' . $insert['image']);
							if ($this->request->hasArgument('dimport') && is_file(PATH_site.'uploads/tx_mvcooking/' . $entries[$i]['image']))
								unlink(PATH_site.'uploads/tx_mvcooking/' . $entries[$i]['image']);
						}
					}
					
					// Kategorien
					$sorting = 0;
					$categories = array('saison', 'type', 'position', 'cout', 'difficulte');
					$catCounts = array();
					foreach ($categories as $cat) {
						$oldIDs2 = array();
						$entries2 = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows('*', 'tx_mvcooking_' . $cat, 'deleted=0 AND hidden=0 AND pid=' . $pid, '', 'sorting ASC', '');
						if (count($entries2) > 0) {
							$sorting++;
							$insert = array();
							$insert['pid'] = $pid;
							$insert['cruser_id'] = $GLOBALS['BE_USER']->user['uid'];
							$insert['sorting'] = $sorting;
							$insert['tstamp'] = time();
							$insert['crdate'] = time();
							$insert['title'] = 'tx_mvcooking_' . $cat;
							$insert['sys_language_uid'] = 0;	// müsste man für jede Sprache anlegen!
							$insert['parent'] = 0;	// was sonst?
							$success = $GLOBALS['TYPO3_DB']->exec_INSERTquery('sys_category', $insert);
							if ($success){
								$parentID = $GLOBALS['TYPO3_DB']->sql_insert_id();
							}
							for ($i=0; $i<count($entries2); $i++) {
								$sorting++;
								$insert['parent'] = $parentID;
								$insert['sorting'] = $sorting;
								$insert['tstamp'] = $entries2[$i]['tstamp'];
								$insert['crdate'] = $entries2[$i]['crdate'];
								$insert['title'] = $entries2[$i]['nom'];
								$insert['sys_language_uid'] = $entries2[$i]['sys_language_uid'];
								$success = $GLOBALS['TYPO3_DB']->exec_INSERTquery('sys_category', $insert);
								if ($success){
									$oldIDs2[$entries2[$i]['uid']] = $GLOBALS['TYPO3_DB']->sql_insert_id();
								}
							}
							// Relationen
							$countIDs = array();
							$insert = array();
							$insert['tablenames'] = 'tx_camaliga_domain_model_content';
							$insert['fieldname'] = 'categories';
							for ($i=0; $i<count($entries); $i++) {
								if ($oldIDs[$entries[$i]['uid']] && $oldIDs2[$entries[$i][$cat]]) {
									$countIDs[$entries[$i][$cat]]++;
									$insert['sorting'] = $countIDs[$entries[$i][$cat]];
									$insert['sorting_foreign'] = $i+1;
									$insert['uid_local'] = $oldIDs2[$entries[$i][$cat]];
									$insert['uid_foreign'] = $oldIDs[$entries[$i]['uid']];
									$catCounts[$entries[$i]['uid']]++;
									$success = $GLOBALS['TYPO3_DB']->exec_INSERTquery('sys_category_record_mm', $insert);
								}
							}
							// Anzahl updaten bei den Kategorien
							$update = array();
							for ($i=0; $i<count($entries2); $i++) {
								if (intval($countIDs[$entries2[$i]['uid']]) > 0) {
									$update['items'] = $countIDs[$entries2[$i]['uid']];
									$success = $GLOBALS['TYPO3_DB']->exec_UPDATEquery('sys_category', 'uid=' . $oldIDs2[$entries2[$i]['uid']], $update);
								}
							}
						}
					}

					// Anzahl updaten bei den Rezept-Elementen
					$update = array();
					for ($i=0; $i<count($entries); $i++) {
						if (intval($catCounts[$entries[$i]['uid']]) > 0) {
							$update['categories'] = $catCounts[$entries[$i]['uid']];
							$success = $GLOBALS['TYPO3_DB']->exec_UPDATEquery('tx_camaliga_domain_model_content', 'uid=' . $oldIDs[$entries[$i]['uid']], $update);
						}
					}
					
					// Meldung
					$this->flashMessageContainer->add(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('LLL:EXT:camaliga/Resources/Private/Language/locallang_be.xlf:import.ok', 'OK'));
					if ($this->request->hasArgument('dimport')) {
						$GLOBALS['TYPO3_DB']->exec_DELETEquery('tx_mvcooking_recette', 'deleted=0 AND hidden=0 AND pid=' . $pid);
						$GLOBALS['TYPO3_DB']->exec_DELETEquery('tx_mvcooking_saison', 'deleted=0 AND hidden=0 AND pid=' . $pid);
						$GLOBALS['TYPO3_DB']->exec_DELETEquery('tx_mvcooking_type', 'deleted=0 AND hidden=0 AND pid=' . $pid);
						$GLOBALS['TYPO3_DB']->exec_DELETEquery('tx_mvcooking_position', 'deleted=0 AND hidden=0 AND pid=' . $pid);
						$GLOBALS['TYPO3_DB']->exec_DELETEquery('tx_mvcooking_cout', 'deleted=0 AND hidden=0 AND pid=' . $pid);
						$GLOBALS['TYPO3_DB']->exec_DELETEquery('tx_mvcooking_difficulte', 'deleted=0 AND hidden=0 AND pid=' . $pid);
						$this->flashMessageContainer->add(\TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('LLL:EXT:camaliga/Resources/Private/Language/locallang_be.xlf:import.del', 'deleted'));
					}
				}
				
				$this->view->assign('entries', $entries);
				$this->view->assign('error', 0);
			} else {
				$this->view->assign('error', 1);
			}
		} else {
			$this->view->assign('error', 1);
		}
	}
	
	/**
	 * action PicasaWeb-import
	 *
	 * @return void
	 */
	public function importPicasaAction() {
		$pid = intval($this->getCurrentPageId());
		$importNr = $this->request->hasArgument('importNr') ? intval($this->request->getArgument('importNr')) : -1;
		$start = $this->request->hasArgument('start') ? intval($this->request->getArgument('start')) : 1;
		$max = $this->request->hasArgument('max') ? intval($this->request->getArgument('max')) : 25;
		$userID = $this->request->hasArgument('userid') ? $this->request->getArgument('userid') : '';
		$albumID = $this->request->hasArgument('albumid') ? $this->request->getArgument('albumid') : '';
		$imgsize = $this->request->hasArgument('imgsize') ? $this->request->getArgument('imgsize') : '720';
		
		if ($userID && $albumID) {
			$url = 'https://picasaweb.google.com/data/feed/api/user/' . $userID . '/albumid/' . $albumID . 
				'?start-index=' . $start . '&max-results=' . $max . '&imgmax=110&thumbsize=104';
			$ch=curl_init();
			curl_setopt($ch,CURLOPT_URL,$url);
			curl_setopt($ch,CURLOPT_RETURNTRANSFER,1);
			$data=curl_exec($ch);
			curl_close($ch);
	
		/*	$dom = new DOMDocument;
			$dom->loadXML($data); // data from cURL request		
			$xpath = new DOMXPath($dom);
			$names = $xpath->query('//feed/entry');
			foreach ($names as $name) {
			    echo $name->nodeValue;
			}*/
			$xml = simplexml_load_string($data);
			$json = json_encode($xml);
			$array = json_decode($json,TRUE);
	
			// Import
			$imported = FALSE;
			$array2 = array();
			$inserted = array();
			$insert = array();
			$insert['pid'] = $pid;
			$insert['tstamp'] = time();
			$insert['crdate'] = time();
			$insert['cruser_id'] = $GLOBALS['BE_USER']->user['uid'];
			
			foreach ($array['entry'] as $i => $entry) {
				$insert['sorting'] = $i+1;
				$insert['title'] = ($entry['summary']) ? $entry['summary'] : $entry['title'];
				$insert['image'] = $this->checkImage($entry['title']);
				$insert['custom1'] = $entry['content']['@attributes']['src'];
				$inserted[] = $insert;
				
				if (($i+1) == $importNr) {
					// Hiermit erhalten wir ein großes Bild:
					$url2 = $entry['id'] . '?imgmax=' . $imgsize;
					$ch=curl_init();
					curl_setopt($ch,CURLOPT_URL,$url2);
					curl_setopt($ch,CURLOPT_RETURNTRANSFER,1);
					$data2=curl_exec($ch);
					curl_close($ch);
					
					$xml2 = simplexml_load_string($data2);
					$json2 = json_encode($xml2);
					$array2 = json_decode($json2,TRUE);
					if ($array2['content']['@attributes']['src'])
						$insert['custom1'] = $array2['content']['@attributes']['src'];
					
					// copy image from the google server
					ob_start();
					$fp = fopen($insert['custom1'], "rb");
					fpassthru($fp);
					fclose($fp);
					$file = ob_get_contents();
					ob_end_clean();
					$fp = fopen(PATH_site . 'uploads/tx_camaliga/' . $insert['image'], "wb+");
					fwrite($fp, $file);
					fclose($fp);
					$insert['custom1'] = '';
					$imported = $insert['image'];
					
					$res4 = $GLOBALS['TYPO3_DB']->exec_SELECTquery(
						'MAX(sorting) AS sorting',
						'tx_camaliga_domain_model_content',
						'pid = ' . $pid);
					$rows = $GLOBALS['TYPO3_DB']->sql_num_rows($res4);
					if ($rows>0) {
						while($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res4)){
							$insert['sorting'] = $row['sorting'] + 10;
						}
						$GLOBALS['TYPO3_DB']->sql_free_result($res4);
					} else $insert['sorting'] = 10;
					
					// save the entry into the DB
					$success = $GLOBALS['TYPO3_DB']->exec_INSERTquery('tx_camaliga_domain_model_content', $insert);
				}
			}
		}
		
		$this->view->assign('start', $start);
		$this->view->assign('max', $max);
		$this->view->assign('imgsize', $imgsize);
		$this->view->assign('userid', (string) $userID);
		$this->view->assign('albumid', (string) $albumID);
		$this->view->assign('imported', $imported);		
		$this->view->assign('result', $inserted);
		$this->view->assign('entries', $array['entry']);
		$this->view->assign('importentry', $array2);
	}

	/**
	 * action CSV import
	 *
	 * @return void
	 */
	public function importCsvAction() {
		if ($this->request->hasArgument('show_it')) {
			$show_it = intval($this->request->getArgument('show_it'));
		} else {
			$show_it = 0;
		}
		if ($this->request->hasArgument('daten_id')) {
			$daten_id = $this->request->getArgument('daten_id');
		} else {
			$daten_id = intval($this->getCurrentPageId());
		}
		if ($this->request->hasArgument('feldtrenner')) {
			$feldtrenner = $this->request->getArgument('feldtrenner');
		} else {
			$feldtrenner = ';';
		}
		if ($this->request->hasArgument('texttrenner')) {
			$texttrenner = $this->request->getArgument('texttrenner');
		} else {
			$texttrenner = '';
		}
		if ($this->request->hasArgument('syslanguid')) {
			$syslanguid = intval($this->request->getArgument('syslanguid'));
		} else {
			$syslanguid = 0;
		}
		if ($this->request->hasArgument('convert')) {
			$convert = $this->request->getArgument('convert');
		} else {
			$convert = 1;
		}
		$listed = -2;
		$output = '';
		$this->nr = 0;
		$insert = array();
		$output = '';
		
		if ($_FILES['uploadedfile'] && is_file($_FILES['uploadedfile']['tmp_name'])) {
			//$this->request->hasArgument('uploadedfile')) {
			//	$uploadedfile = $this->request->getArgument('uploadedfile');
			$dateiname = $_FILES['uploadedfile']['tmp_name'];
			
			// search all categories
			$catArray = array();
			$res = $GLOBALS['TYPO3_DB']->exec_SELECTquery('uid, title',
					'sys_category',
					'hidden=0 AND deleted=0');
			$rows = $GLOBALS['TYPO3_DB']->sql_num_rows($res);
			if ($rows>0) {
				while($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res)){
					$catArray[$row['title']] = $row['uid'];
				}
			}
			$GLOBALS['TYPO3_DB']->sql_free_result($res);
			
			$lines = array();
			$lines = file($dateiname);
			if ( count($lines) > 1 ) {
				$nr=0;
				$sorting=0;
				$fields_values = array();
				$fields_values['pid'] = $daten_id;
				$fields_values['tstamp'] = time();
				$fields_values['crdate'] = time();
				$fields_values['sys_language_uid'] = $syslanguid;
				$fields_values['cruser_id'] = $GLOBALS['BE_USER']->user["uid"];
				$handle = fopen ($dateiname, "r");              // Datei zum Lesen oeffnen
					
				if ($texttrenner) {
					while ( ($Felder = fgetcsv ($handle, 1000, $feldtrenner, $texttrenner)) !== FALSE ) {
						if ($nr==0) {
							$fields_names = $Felder;
							$nr++;
						} else if ($Felder[0]) {
							$sorting++;
							$fields_values['sorting'] = $sorting;
							$insert[] = $this->insertLine($fields_names, $fields_values, $Felder, $show_it, $convert, $catArray);
							$nr++;
						}
					}
				} else {
					while ( ($Felder = fgetcsv ($handle, 1000, $feldtrenner)) !== FALSE ) {
						if ($nr==0) {
							$fields_names = $Felder;
							$nr++;
						} else if ($Felder[0]) {
							$sorting++;
							$fields_values['sorting'] = $sorting;
							$insert[] = $this->insertLine($fields_names, $fields_values, $Felder, $show_it, $convert, $catArray);
							$nr++;
						}
					}
				}
				fclose ($handle);
				if ($show_it != 2)
					$listed = ($nr-1);
			} else {
				$listed = -1;
			}
		}
		
		if (count($insert) > 0) {
			$output = $this->build_table($insert);
		}
		
		$this->view->assign('debug', $output);
		$this->view->assign('listed', $listed);
		$this->view->assign('imported', $this->nr);
		$this->view->assign('show_it', $show_it);
		$this->view->assign('convert', $convert);
		$this->view->assign('daten_id', $daten_id);
		$this->view->assign('feldtrenner', $feldtrenner);
		$this->view->assign('texttrenner', $texttrenner);
		$this->view->assign('syslanguid', $syslanguid);
	}
	
	/**
	 * Inserts a line to the database
	 *
	 * @return	array
	 */
	function insertLine($names, $values, $Felder, $show_it, $convert, $catArray) {
		for ($i=0; $i<count($names); $i++) {
			$feld = $names[$i];
			if (substr($feld, 0, 8) != 'category') {
				if ($convert)
					$values[$feld] = trim(iconv('iso-8859-1','utf-8',$Felder[$i]));
				else
					$values[$feld] = trim($Felder[$i]);
			}
		}
		if ($show_it < 2) {
			$GLOBALS['TYPO3_DB']->exec_INSERTquery('tx_camaliga_domain_model_content', $values);
			$values['uid'] = $GLOBALS['TYPO3_DB']->sql_insert_id();
			
			if ($values['uid'] > 0) {
				// Zähler hochsetzen
				$this->nr++;
				// Kategorie-Relationen einfügen? Kategorien müssen vorhanden sein!
				$cats = 0;
				$updateA = array();
				for ($i=0; $i<count($names); $i++) {
					$feld = $names[$i];
					if (substr($feld, 0, 8) == 'category' && $values['uid']) {
						$cat = substr($feld, 9);
						if ($cat) {
							// Kategorie im Header angegeben
							if (trim($Felder[$i]))
								$catName = ($convert) ? trim(iconv('iso-8859-1','utf-8',$cat)) : trim($cat);
							else 
								$catName = '';
						} else {
							// Kategorie in den Zeilen angegeben
							$catName = ($convert) ? trim(iconv('iso-8859-1','utf-8',$Felder[$i])) : trim($Felder[$i]);
						}
						$catID = $catArray[$catName];
						if ($catID > 0) {
							// Kategorie-Relationen einfügen
							$mmInsertArray = array('tablenames' => 'tx_camaliga_domain_model_content', 'fieldname' => 'categories');
							$mmInsertArray['uid_local'] = $catID;	// Die Kategorie
							$mmInsertArray['uid_foreign'] = $values['uid'];			// Das Camaliga-Element
							$mmInsertArray['sorting'] = ($cats+1)*10;
							$mmInsertArray['sorting_foreign'] = ($cats+1)*10;
							$success = $GLOBALS['TYPO3_DB']->exec_INSERTquery('sys_category_record_mm', $mmInsertArray);
							if ($success) $cats++;
						}
					}
				}
				if ($cats > 0) {
					$updateA['categories'] = $cats;
					$GLOBALS['TYPO3_DB']->exec_UPDATEquery('tx_camaliga_domain_model_content', 'uid=' . $values['uid'], $updateA);
				}
			}
		}
		return $values;
	}

	/**
	 * Aray nach Tabelle
	 *
	 * @return	string
	 */
	function build_table($array){
		// start table
		$html = '<table>';
		// header row
		$html .= '<tr>';
		foreach($array[0] as $key=>$value){
			$html .= '<th>' . $key . '</th>';
		}
		$html .= '</tr>';
	
		// data rows
		foreach( $array as $key=>$value){
			$html .= '<tr>';
			foreach($value as $key2=>$value2){
				$html .= '<td>' . $value2 . '</td>';
			}
			$html .= '</tr>';
		}
	
		// finish table and return it
		$html .= '</table>';
		return $html;
	}
	
	/**
	 * Prüft, ob ein Bild schon vorhanden ist
	 *
	 * @return string
	 */
	function checkImage($bild) {
		if (is_file(PATH_site . 'uploads/tx_camaliga/' . $bild)) {
			// wenn das Bild schon da ist, den Dateinamen ändern!
			for ($j=1;$j<500;$j++) {
				if (!is_file(PATH_site . 'uploads/tx_camaliga/' . $j . '_' . $bild)) {
					$bild = $j . '_' . $bild;
					break;
				}
			}
		}
		return $bild;
	}
}
?>